"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.checkNodeVersion = void 0;
const dev_1 = require("umi/dist/cli/dev");
const service_1 = require("umi/dist/service/service");
const utils_1 = require("@umijs/utils");
const constants_1 = require("./constants");
(0, utils_1.catchUnhandledRejection)();
const ver = parseInt(process.version.slice(1));
function checkNodeVersion(minVersion, message) {
    if (ver < minVersion) {
        utils_1.logger.error(message ||
            `Your node version ${ver} is not supported, please upgrade to ${minVersion} or above except 15 or 17.`);
        process.exit(1);
    }
}
exports.checkNodeVersion = checkNodeVersion;
async function run(opts = {}) {
    checkNodeVersion(constants_1.MIN_NODE_VERSION);
    (0, utils_1.checkLocal)();
    (0, utils_1.setNodeTitle)(constants_1.FRAMEWORK_NAME);
    (0, utils_1.setNoDeprecation)();
    const args = (0, utils_1.yParser)(process.argv.slice(2), {
        alias: {
            version: ['v'],
            help: ['h'],
        },
        boolean: ['version'],
    });
    const command = args._[0];
    if ([constants_1.DEV_COMMAND, 'setup'].includes(command)) {
        process.env.NODE_ENV = 'development';
    }
    else if (command === 'build') {
        process.env.NODE_ENV = 'production';
    }
    opts.presets = opts?.presets
        ? opts?.presets.concat([require.resolve('./preset')])
        : [require.resolve('./preset')];
    if (opts?.presets) {
        process.env.UMI_PRESETS = opts.presets.join(',');
    }
    if (!opts.defaultConfigFiles && command === constants_1.DEV_COMMAND) {
        (0, dev_1.dev)();
    }
    else if (command === 'version' || command === 'v') {
        const version = require('../package.json').version;
        console.log(`alita@${version}`);
    }
    else {
        try {
            await new service_1.Service({
                defaultConfigFiles: opts.defaultConfigFiles || null,
            }).run2({
                name: args._[0],
                args,
            });
        }
        catch (e) {
            utils_1.logger.error(e);
            utils_1.printHelp.exit();
            process.exit(1);
        }
    }
}
exports.run = run;
